using Attribute;
using Common;
using Dto;
using Vo;
using Enums;
using Filters;
using Infrastructure;
using Infrastructure.Model;
using Mapster;
using Microsoft.AspNetCore.Mvc;
using Middleware;
using Model;
using Services;
using Model.Base;

namespace Controllers
{
    /// <summary>
    /// AppBottomNavs)Controller
    /// </summary>
    // [Route("AppBottomNavs")]
    // [ApiExplorerSettings(GroupName = "AppBottomNavs")]
    public class AppBottomNavsController : BaseController
    {
        /// <summary>
        /// api分组接口
        /// </summary>
        private readonly IAppBottomNavsService _AppBottomNavsService;


        public AppBottomNavsController(IAppBottomNavsService AppBottomNavsService)
        {
            _AppBottomNavsService = AppBottomNavsService;

        }

        /// <summary>
        /// app底部导航列表
        /// </summary>
        /// <param name="parm">请求参数</param>
        /// <returns>app底部导航列表</returns>
        [HttpGet]
        [Route("/v1/api/AppBottomNavs/list")]
        public IActionResult List([FromQuery] AppBottomNavsListDto parm)
        {
            var response = _AppBottomNavsService.List(parm);
            return SUCCESS(response);
        }




        /// <summary>
        /// app底部导航详情
        /// </summary>
        /// <param name="parm">请求参数</param>
        /// <returns>app底部导航详情</returns>
        [HttpGet]
        [Route("/v1/api/AppBottomNavs/query")]
        public IActionResult Query([FromQuery] AppBottomNavsQueryDto parm)
        {
            var response = _AppBottomNavsService.Queryable()
                .First(x => x.id == parm.id)
                .Adapt<AppBottomNavsQueryVo>() ?? new AppBottomNavsQueryVo();
            return SUCCESS(response);
        }




        /// <summary>
        /// app底部导航添加
        /// </summary>
        /// <param name="parm">请求参数</param>
        /// <returns>app底部导航添加</returns>
        [HttpPost]
        [Route("/v1/api/AppBottomNavs/add")]
        public IActionResult Add([FromBody] AppBottomNavsAddDto parm)
        {
            var modal = parm.Adapt<AppBottomNavs>().ToCreate(HttpContext);
            var response = _AppBottomNavsService.Add(modal);
            return SUCCESS(response);
        }




        /// <summary>
        /// app底部导航修改
        /// </summary>
        /// <param name="parm">请求参数</param>
        /// <returns>app底部导航修改</returns>
        [HttpPut]
        [Route("/v1/api/AppBottomNavs/update")]
        public IActionResult Update([FromBody] AppBottomNavsUpdateDto parm)
        {
            var modal = parm.Adapt<AppBottomNavs>().ToUpdate(HttpContext);
            var response = _AppBottomNavsService.Update(modal, true);
            return SUCCESS(response);
        }




        /// <summary>
        /// app底部导航删除
        /// </summary>
        /// <param name="Id">ID</param>
        /// <returns>app底部导航删除</returns>
        [HttpDelete]
        [Route("/v1/api/AppBottomNavs/delete/{id}")]
        public IActionResult Delete(int id)
        {
            var response = _AppBottomNavsService.Delete(id);
            return SUCCESS(response);
        }






    }
}