using Attribute;
using Common;
using Dto;
using Vo;
using Enums;
using Filters;
using Infrastructure;
using Infrastructure.Model;
using Mapster;
using Microsoft.AspNetCore.Mvc;
using Middleware;
using Model;
using Services;
using Model.Base;

namespace Controllers
{
    /// <summary>
    /// PageUpdateInfo)Controller
    /// </summary>
    // [Route("PageUpdateInfo")]
    // [ApiExplorerSettings(GroupName = "PageUpdateInfo")]
    public class PageUpdateInfoController : BaseController
    {
        /// <summary>
        /// api分组接口
        /// </summary>
        private readonly IPageUpdateInfoService _PageUpdateInfoService;


        public PageUpdateInfoController(IPageUpdateInfoService PageUpdateInfoService)
        {
            _PageUpdateInfoService = PageUpdateInfoService;

        }

        /// <summary>
        /// 页面模板更新信息列表
        /// </summary>
        /// <param name="parm">请求参数</param>
        /// <returns>页面模板更新信息列表</returns>
        [HttpGet]
        [Route("/v1/api/PageUpdateInfo/list")]
        public IActionResult List([FromQuery] PageUpdateInfoListDto parm)
        {
            var response = _PageUpdateInfoService.List(parm);
            return SUCCESS(response);
        }




        /// <summary>
        /// 页面模板更新信息详情
        /// </summary>
        /// <param name="parm">请求参数</param>
        /// <returns>页面模板更新信息详情</returns>
        [HttpGet]
        [Route("/v1/api/PageUpdateInfo/query")]
        public IActionResult Query([FromQuery] PageUpdateInfoQueryDto parm)
        {
            var response = _PageUpdateInfoService.Queryable()
                .First(x => x.id == parm.id)
                .Adapt<PageUpdateInfoQueryVo>() ?? new PageUpdateInfoQueryVo();
            return SUCCESS(response);
        }




        /// <summary>
        /// 页面模板更新信息添加
        /// </summary>
        /// <param name="parm">请求参数</param>
        /// <returns>页面模板更新信息添加</returns>
        [HttpPost]
        [Route("/v1/api/PageUpdateInfo/add")]
        public IActionResult Add([FromBody] PageUpdateInfoAddDto parm)
        {
            var modal = parm.Adapt<PageUpdateInfo>().ToCreate(HttpContext);
            var response = _PageUpdateInfoService.Add(modal);
            return SUCCESS(response);
        }




        /// <summary>
        /// 页面模板更新信息修改
        /// </summary>
        /// <param name="parm">请求参数</param>
        /// <returns>页面模板更新信息修改</returns>
        [HttpPut]
        [Route("/v1/api/PageUpdateInfo/update")]
        public IActionResult Update([FromBody] PageUpdateInfoUpdateDto parm)
        {
            var modal = parm.Adapt<PageUpdateInfo>().ToUpdate(HttpContext);
            var response = _PageUpdateInfoService.Update(modal, true);
            return SUCCESS(response);
        }




        /// <summary>
        /// 页面模板更新信息删除
        /// </summary>
        /// <param name="Id">ID</param>
        /// <returns>页面模板更新信息删除</returns>
        [HttpDelete]
        [Route("/v1/api/PageUpdateInfo/delete/{id}")]
        public IActionResult Delete(int id)
        {
            var response = _PageUpdateInfoService.Delete(id);
            return SUCCESS(response);
        }




        /// <summary>
        /// 页面模板更新信息刷新文件
        /// </summary>
        /// <returns>页面模板更新信息刷新文件</returns>
        [HttpGet]
        [Route("/v1/api/PageUpdateInfo/updateTemplate")]
        public IActionResult UpdateTemplate([FromQuery] PageUpdateInfoListDto parm)
        {
            _PageUpdateInfoService.UpdateTemplate(parm);
            return SUCCESS("ok");
        }






    }
}