using Attribute;
using Dto;
using Vo;
using Model;
using Model.Base;

using Repository;
using Service;
using Microsoft.AspNetCore.Mvc;

namespace Services
{
    /// <summary>
    /// app版本管理Service业务层处理
    /// </summary>
    [AppService(ServiceType = typeof(IAppVersionService), ServiceLifetime = LifeTime.Transient)]
    public class AppVersionService : BaseService<AppVersion>, IAppVersionService
    {
        /// <summary>
        /// app版本管理-列表
        /// </summary>
        /// <param name="parm">请求参数</param>
        /// <returns>app版本管理列表</returns>
        public PagedInfo<AppVersionListVo> List([FromQuery] AppVersionListDto parm)
        {
            //开始拼装查询条件
            var predicate = Expressionable.Create<AppVersion>();
            predicate = predicate.AndIF(!string.IsNullOrEmpty(parm.versionNum), m => m.versionNum.Contains(parm.versionNum));
            predicate = predicate.AndIF(!string.IsNullOrEmpty(parm.title), m => m.title.Contains(parm.title));
            predicate = predicate.AndIF(!string.IsNullOrEmpty(parm.info), m => m.info.Contains(parm.info));
            var response = Queryable()
                .Where(predicate.ToExpression())
                .OrderByDescending(m => m.id)
                .ToPage<AppVersion, AppVersionListVo>(new PagerInfo());
            return response;
        }













    }
}
