using Attribute;
using Dto;
using Vo;
using Model;
using Model.Base;

using Repository;
using Service;
using Microsoft.AspNetCore.Mvc;
using Aliyun.OSS;
using Common;
using System.Text.RegularExpressions;
using Infrastructure.Model;
using Base;

namespace Services
{
    /// <summary>
    /// 页面模板更新信息Service业务层处理
    /// </summary>
    [AppService(ServiceType = typeof(IPageUpdateInfoService), ServiceLifetime = LifeTime.Transient)]
    public class PageUpdateInfoService : BaseService<PageUpdateInfo>, IPageUpdateInfoService
    {
        /// <summary>
        /// 页面模板更新信息-列表
        /// </summary>
        /// <param name="parm">请求参数</param>
        /// <returns>页面模板更新信息列表</returns>
        public PagedInfo<PageUpdateInfoListVo> List([FromQuery] PageUpdateInfoListDto parm)
        {
            //开始拼装查询条件
            var predicate = Expressionable.Create<PageUpdateInfo>();
            predicate = predicate.AndIF(!string.IsNullOrEmpty(parm.kind), m => m.kind.Contains(parm.kind));
            var response = Queryable()
                .Where(predicate.ToExpression())
                .OrderByDescending(m => m.id)
                .ToPage<PageUpdateInfo, PageUpdateInfoListVo>(new PagerInfo());
            return response;
        }
        


        /// <summary>
        /// 页面模板更新信息-刷新文件
        /// </summary>
        /// <param name="parm">请求参数</param>
        /// <returns>页面模板更新信息刷新文件</returns>
        public void UpdateTemplate([FromQuery] PageUpdateInfoListDto parm)
        {
            OssConfigs ossConfigs = new();
            AppSettings.Bind("OssConfigs", ossConfigs);
            GetSystemFiles(ossConfigs, parm.kind);
            foreach (string filename in SystemFiles)
            {
                string template = filename.Substring(filename.LastIndexOf("/") + 1);
                if (template.EndsWith(".html"))
                {
                    PageUpdateInfo check = GetFirst(m => m.modulePath == template && m.kind == parm.kind);
                    if (check == null)
                    {
                        string ModuleContent = Function.GetNetFileContent(ossConfigs.Host + "template/app/" + parm.kind + "/" + template);
                        if (!string.IsNullOrEmpty(ModuleContent))
                        {
                            string admintitle = "";
                            string title = "";
                            Match match = Regex.Match(ModuleContent, "<title>.*?</title>", RegexOptions.IgnoreCase);
                            if (match.Success)
                            {
                                admintitle = match.Value.Replace("<title>", "").Replace("</title>", "");
                                if (admintitle.Contains("-"))
                                {
                                    title = admintitle.Substring(admintitle.LastIndexOf("-") + 1);
                                }
                                else
                                {
                                    title = admintitle;
                                }
                            }
                            Add(new PageUpdateInfo()
                            {
                                createDate = DateTime.Now,
                                updateDate = DateTime.Now,
                                kind = parm.kind,
                                leftAction1 = "{\"Url\":\"GoBack#{\\\"Level\\\":\\\"1\\\"}\",\"Jump\":\"1\",\"Kind\":\"2\"}",
                                leftBtn1 = "static/images/left.png",
                                skidFlag = true,
                                showScrollBar = false,
                                title = title,
                                showTitle = true,
                                statusBarStyle = "default",
                                textColor = "FFFFFF",
                                backgroudColor = "FD7538",
                                modulePath = template,
                                moduleVersion = 1,
                            });
                        }
                    }
                }
            }
        }
        List<string> SystemFiles;
        private void GetSystemFiles(OssConfigs ossConfigs, string Kind = "default")
        {
            SystemFiles = new List<string>();
            var client = new OssClient(ossConfigs.Endpoint, ossConfigs.Key, ossConfigs.Secret);
            var listObjectsRequest = new ListObjectsRequest(ossConfigs.BucketName);
            listObjectsRequest.MaxKeys = 1000;
            listObjectsRequest.Prefix = "template/app/" + Kind + "/";
            var result = client.ListObjects(listObjectsRequest);
            foreach (var summary in result.ObjectSummaries)
            {
                SystemFiles.Add(summary.Key);
            }
        }
    }
}
